===========
Django Suit
===========

**Modern theme for Django admin interface**.

Django Suit is alternative theme/skin/extension for `Django <http://www.djangoproject.com>`_ administration interface.

* Project home: http://djangosuit.com/
* Live demo v1: http://djangosuit.com/admin/
* Live demo v2.0 alpha 1: http://v2.djangosuit.com/admin/


License
=======

* Django Suit is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.
* Licence and pricing: http://djangosuit.com/pricing/


Docs & Support
==============

* Documentation v2: http://django-suit.readthedocs.org/en/v2/
* Documentation v1: http://django-suit.readthedocs.org/en/latest/
* Support: http://djangosuit.com/support/
* Follow `on Twitter <http://twitter.com/DjangoSuit>`_ to get latest news


Changelog
=========

**Note:** Django Suit v2.0 is in active development and not yet ready for production use.

Read more here: Todo: Add issue refernce


Contributing
============

See `Contributing documentation <http://django-suit.readthedocs.org/en/v2/contribute.html>`_


Build Status
============

Django Suit uses Travis CI to perform tests on different Django and Python versions.

Tested using Python: 2.7-3.4 and PyPy. Django: 1.9+ and Django Suit v2.0 alpha:

.. |v2| image:: https://travis-ci.org/darklow/django-suit.png?branch=v2
   :alt: Build Status - v2 branch
   :target: http://travis-ci.org/darklow/django-suit

.. |develop| image:: https://travis-ci.org/darklow/django-suit.png?branch=develop
   :alt: Build Status - develop branch
   :target: http://travis-ci.org/darklow/django-suit

|v2| |develop|


Preview
=======


.. image:: https://cloud.githubusercontent.com/assets/445304/12699480/3eee898e-c7c5-11e5-931c-ba1b0cabdecb.png
:alt: Django Suit Preview
   :target: http://v2.djangosuit.com/admin/
